@@ -26,16 +26,14 @@ function (thetas, lambda0) {
     S[unq.indT, ] <- rowsum(lambda0[ind.L1] * exp.eta.s, indT, reorder = FALSE)
     log.survival <- - exp(eta.tw) * S
     log.p.tb <- d * log.hazard + log.survival
-    log.p.b <- if (ncz == 1) {
-        dnorm(b, sd = sqrt(D), log = TRUE)
+    log.p.b <- if (control$typeGH == "simple") {
+        rep(dmvnorm(b, rep(0, ncz), D, TRUE), each = n)
     } else {
-        if (diag.D) {
-            rowSums(dnorm(b, sd = rep(sqrt(D), each = k), log = TRUE))
-        } else {
-            dmvnorm(b, rep(0, ncz), D, TRUE)
-        }
+        matrix(dmvnorm(do.call(rbind, lis.b), rep(0, ncz), D, TRUE), n, k, byrow = TRUE)
     }
-    p.ytb <- exp((log.p.yb + log.p.tb) + rep(log.p.b, each = n))
+    p.ytb <- exp(log.p.yb + log.p.tb + log.p.b)
+    if (control$typeGH != "simple")
+        p.ytb <- p.ytb * VCdets
     dimnames(p.ytb) <- NULL
     p.yt <- c(p.ytb %*% wGH)
     p.byt <- p.ytb / p.yt
